#########1#########2#########3#########4#########5#########6#########7#########8
# VOS1_2                                                                       #
#########1#########2#########3#########4#########5#########6#########7#########8
# Uno script per importare e analizzare i report opinioni degli studenti
# in formato cartaceo. La working directory deve essere impostata sulla
# cartella contenente le due cartelle con i file di testo dei dati e i file  
# .xlsx dei metadati. La subcartella chiamata filedati deve contenere i file  
# delle schede da importare, il cui nome deve corrispondere al codice 
# dell'insegnamento mentre una subdirectory chiamata filemetadati deve contenere 
# i metadati (metadati delle domande, metadati degli insegnamenti) in formato
# .xlsx.
# Lo script conduce l'analisi per singolo anno e presenta risultati riassuntivi
# per tutti gli insegnamenti
# Lo script è progettato per lavorare in MacOS. In Win è possibile si debbano
# cambiare i caratteri / con \\.
# Prima di far girare lo script è necessario installare i packages.
#########1#########2#########3#########4#########5#########6#########7#########8
# carica packages in workspace
library(openxlsx)
library(doBy)
library(reshape2)
library(ggplot2)
library(plyr)
#########1#########2#########3#########4#########5#########6#########7#########8
wd <- getwd()
#########1#########2#########3#########4#########5#########6#########7#########8
# se desideri far girare di nuovo lo script riparti da qui
#########1#########2#########3#########4#########5#########6#########7#########8
# definisci le opzioni
# output <- "breve" omette l'analisi per singolo insegnamento e genera solo
# analisi riassuntive per gli insegnamenti caricati
# output <- "lungo" genera entrambe le analisi
output <- "lungo"
# inferenziali <- "no" non genera statistiche inferenziali, qualsiasi altro 
# valore le genera
inferenziali <- "no"
#########1#########2#########3#########4#########5#########6#########7#########8
# prepara tutti i file di dati e metadati
#########1#########2#########3#########4#########5#########6#########7#########8
setwd(paste(wd,"/filedati",sep = ""))
filelist <- list.files()
#########1#########2#########3#########4#########5#########6#########7#########8
# carica i dati grezzi nell'oggetto VOSdati, la prima colonna contiene il codice
# dell'insegnamento, identico a quello che si può ricavare dai metadati degli
# insegnamenti. NB probabilmente si può fare con plyr.
# Se la tabella è già disponibile in altro formato questa sezione può essere
# omessa
#########1#########2#########3#########4#########5#########6#########7#########8
# inizializzazione
i <- 1
codiceins <- basename(filelist[i])
codiceins <- substr(codiceins, 1, as.integer(gregexpr(pattern ='.txt', 
                                                      codiceins))-1)
scheda <- read.csv2(filelist[i], header = F, na.strings = "", 
                    stringsAsFactors = FALSE)
scheda <- scheda[,3:(dim(scheda)[2]-1)]
scheda <- scheda[scheda$V3 == "RETRO",]
scheda <- cbind(rep(codiceins,dim(scheda)[1]),scheda[,2:dim(scheda)[2]])
colnames(scheda)[1] <- "codIns"
VOSdati <- scheda
# loop, aggiunge gli altri insegnamenti in coda al primo
if (length(filelist)>1) {
  for (i in 2:length(filelist)){
    codiceins <- basename(filelist[i])
    codiceins <- substr(codiceins, 1, as.integer(gregexpr(pattern ='.txt', 
                                                          codiceins))-1)
    scheda <- read.csv2(filelist[i], header = F, na.strings = "", 
                        stringsAsFactors=FALSE)
    scheda <- scheda[,3:(dim(scheda)[2]-1)]
    scheda <- scheda[scheda$V3 == "RETRO",]
    scheda <- cbind(rep(codiceins,dim(scheda)[1]),scheda[,2:dim(scheda)[2]])
    colnames(scheda)[1] <- "codIns"
    VOSdati <- rbind(VOSdati,scheda)
  }
}
# rimuove gli oggetti inutili
rm(scheda, codiceins, filelist)
# recupera i metadati delle domande. L'oggetto domande contiene le domande
setwd(paste(wd,"/filemetadati",sep = ""))
Opinioni_metadata <- read.xlsx("Opinioni_metadata.xlsx")
Opinioni_metadata$Codice_domanda <- as.factor(Opinioni_metadata$Codice_domanda)
Opinioni_metadata$Tipo <- as.factor(Opinioni_metadata$Tipo)
domande <- unique(Opinioni_metadata[,c(2:4,8)])
valutative <- subset(domande,domande$Tipo == "Valutativa")
votoCorso <- subset(domande,domande$Tipo == "Voto_corso")
informative1 <- subset(domande,domande$Tipo == "Informativa_1")
informative2 <- subset(domande,domande$Tipo == "Informativa_2")
informative3 <- subset(domande,domande$Tipo == "Informativa_3")
informative3_1 <- subset(domande,domande$Tipo == "Informativa_3_1")
informative4 <- subset(domande,domande$Tipo == "Informativa_4")
cod_domande <- levels(domande$Codice_domanda)
colnames(VOSdati)[2:dim(VOSdati)[2]] <- cod_domande
# recupera i metadati dei corsi
corsiMetadata <- read.xlsx("corsiMetadata.xlsx")
# scrive il file in formato .txt e xlsx
outfilename <- paste(wd,"/",basename(wd), sep = "")
write.table(VOSdati, file = paste(outfilename,".txt"), 
            append = FALSE, sep = "\t", col.names = TRUE, 
            row.names = F)
write.xlsx(VOSdati, file = paste(outfilename,".xlsx"))
# Produce oggetti per i diversi tipi di domande.
# I livelli delle risposte sono trasformati in fattori.
# xxwide contiene le risposte come fattori in formato wide
# xxlong contiene le risposte come fattori in formato long
# xxnum contiene le risposte come livelli numerici in formato long
# prima per le domande valutative
selval <- which(colnames(VOSdati) %in% valutative$Codice_domanda)
VOSvalwide <- VOSdati[,c(1, selval)]
Valfactfun <- function(x) {
  factor(x, exclude = NULL, ordered = T, levels = c("A","B","C","D","NR"))
}
VOSvalwide[2:dim(VOSvalwide)[2]] <- 
  catcolwise(Valfactfun)(VOSvalwide[2:dim(VOSvalwide)[2]])
VOSvalwide$B3 <- factor(VOSvalwide$B3, levels = c("D","C","B","A","NR"))
# VOSvallong può essere usato per stacked bar plots con ggplot2
VOSvallong <- melt(VOSvalwide, id.vars = "codIns")
# genera un warning perché B3 ha una struttura diversa dei livelli
# sarebbe meglio che la domanda fosse riformulata nei questionari
colnames(VOSvallong)[2:3] <- c("domanda", "codRisposta")
VOSvalnumwide <- VOSvalwide
VOSvalnumwide[,2:dim(VOSvalnumwide)[2]] <- 
  catcolwise(as.numeric)(VOSvalnumwide[2:dim(VOSvalnumwide)[2]])
VOSvalnum <- melt(VOSvalnumwide, id.vars = "codIns")
colnames(VOSvalnum)[2:3] <- c("domanda", "codRisposta")
selvalcorso <- which(colnames(VOSdati) %in% votoCorso$Codice_domanda)
VOSvalcorso <- VOSdati[,c(1, selvalcorso)]
VOSvalcorsonum <- VOSvalcorso 
VOSvalcorsonum$E <- as.numeric(factor(VOSvalcorsonum$E, 
                                      exclude = NULL, ordered = T, 
                                      levels = c("A","B","C","D","E","NR")))
# genera un dataframe per confrontare la mediana delle risposte valutative
# per singolo studente con la risposta E
MediananoNA <- function(x, na.omit = T) {
  if (na.omit)
    x <- x[!is.na(x)]
  mediana <- median(x) 
}
VOSvalmedians <- apply(VOSvalnumwide[,2:14],1,MediananoNA)
VOSvalmedians <- as.data.frame(cbind(as.numeric(VOSvalmedians), 
                                     as.numeric(VOSvalcorsonum$E)))
VOSvalmedians$codIns <- VOSvalnumwide$codIns
colnames(VOSvalmedians)[1:2] <- c("medval", "E")
# genera valori numerici per le statistiche (mediana, lower and upper hinge), 
# per insegnamento, per le domande valutative (VOSvalsummary) 
# e un dato riassuntivo per le mediane di tutte le domande (VOSvalscore)
mystats <- function(x, na.omit=TRUE){
  if (na.omit)
    x <- x[!is.na(x)]
  mediana <- median(x)
  LH <- quantile(x, 0.25)
  UH <- quantile(x, 0.75)
  return(c(mediana = mediana, LH = LH, UH = UH))
}
VOSvalsummary <- summaryBy(codRisposta ~ codIns + domanda, 
                           data=subset(VOSvalnum, domanda != "E"), FUN=mystats)
colnames(VOSvalsummary)[3:5] <- c("mediana", "LH","UH")
VOSvalscore <- summaryBy(mediana ~ codIns, 
                         data=VOSvalsummary, FUN=mystats)
colnames(VOSvalscore)[2:4] <- c("mediana", "LH","UH")
# Poi per le domande informative, per le quali non viene condotta
# la conversione in numeri. La codifica dei nomi degli oggetti è simile
# a quella appena descritta.
selinf1 <- which(colnames(VOSdati) %in% informative1$Codice_domanda)
VOSinf1wide <- VOSdati[,c(1, selinf1)]
VOSinf1wide[2:dim(VOSinf1wide)[2]] <- 
  catcolwise(Valfactfun)(VOSinf1wide[2:dim(VOSinf1wide)[2]])
VOSinf1long <- melt(VOSinf1wide, id.vars = "codIns")
colnames(VOSinf1long)[2:3] <- c("domanda", "codRisposta")
selinf2 <- which(colnames(VOSdati) %in% informative2$Codice_domanda)
VOSinf2wide <- VOSdati[,c(1, selinf2)]
# qui (e per le successive) non ha senso trasformare in fattori
VOSinf2long <- melt(VOSinf2wide, id.vars ="codIns")
colnames(VOSinf2long)[2:3] <- c("domanda", "codRisposta")
selinf3 <- which(colnames(VOSdati) %in% informative3$Codice_domanda)
VOSinf3wide <- VOSdati[,c(1, selinf3)]
VOSinf3long <- melt(VOSinf3wide, id.vars ="codIns")
colnames(VOSinf3long)[2:3] <- c("domanda", "codRisposta")
selinf3_1 <- which(colnames(VOSdati) %in% informative3_1$Codice_domanda)
VOSinf3_1wide <- VOSdati[,c(1, selinf3_1)]
VOSinf3_1long <- melt(VOSinf3_1wide, id.vars ="codIns")
colnames(VOSinf3_1long)[2:3] <- c("domanda", "codRisposta")
selinf4 <- which(colnames(VOSdati) %in% informative4$Codice_domanda)
VOSinf4 <- VOSdati[,c(1, selinf4)]
VOSinf4long <- melt(VOSinf4, id.vars ="codIns")
colnames(VOSinf4long)[2:3] <- c("domanda", "codRisposta")
#########1#########2#########3#########4#########5#########6#########7#########8
# Questa sezione genera i report per singolo insegnamento;
# è attiva se output == "lungo".
#########1#########2#########3#########4#########5#########6#########7#########8
if (output == "lungo") {
  for (i in 1:length(levels(VOSdati$codIns))){
    corsiTemp <- subset(corsiMetadata, codIns == levels(VOSdati$codIns)[i])
    cat("\n***** ", levels(VOSdati$codIns)[i]," *****", sep="")
    cat("\n***** ", corsiTemp$insegnamento, "; corso ", corsiTemp$CDS,
        ", anno ",corsiTemp$anno, ", cfu ", corsiTemp$cfuTot," *****", sep="")
    cat("\n***** Responsabile: ", corsiTemp$responsabile,", qualifica: ", 
        corsiTemp$status, " *****\n", sep="")
    cat("\n***** Domande valutative *****\n")
    for (j in 1:dim(valutative)[1]){
      cat(as.character(valutative$Codice_domanda[j]), 
          valutative$Testo_domanda[j], "\n", sep = " ")
    }
    cat("\n***** Codici risposte *****\n")
    codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                         Codice_domanda == valutative$Codice_domanda[1])
    for (j in 1:dim(codRisTemp)[1]){
      cat(as.character(codRisTemp$Cod_risposta[j]), 
          codRisTemp$Testo_risposta[j], "\n", sep = " ")
    }
    valTemp <- subset(VOSvallong, codIns == levels(VOSdati$codIns)[i])
    if(sum(complete.cases(valTemp))>0){
      stackbar <- ggplot(data = valTemp, 
                          mapping = aes(domanda, fill = codRisposta))
      print(stackbar + geom_bar() +
        labs(y = "conta", fill = "risposta", 
           title = paste(levels(VOSdati$codIns)[i], "Valutative", sep = " ")))
      cat("\n***** Box plots *****\n")
      valTemp <- subset(VOSvalnum, codIns == levels(VOSdati$codIns)[i])
      boxplot <- ggplot(data = valTemp, 
                      mapping = aes(x = domanda, y = codRisposta))
      print(boxplot + geom_boxplot(notch = T, na.rm = T) +
            labs(y = "punteggio", fill = "domanda", 
                 title = paste(levels(VOSdati$codIns)[i], 
                               "Valutative", sep = " ")))
      } else {
        cat("\n***** dati non disponibili *****\n")
    }
    cat("\n***** Voto del corso *****\n")
    cat("\ndomanda E\n")
    codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                         Codice_domanda == "E")
    for (j in 1:dim(codRisTemp)[1]){
      cat(as.character(codRisTemp$Cod_risposta[j]), 
          codRisTemp$Testo_risposta[j], "\n", sep = " ")
    }
    valTemp <- subset(VOSvalcorso, codIns == levels(VOSdati$codIns)[i])
    if(sum(complete.cases(valTemp))>0){
    stackbar <- ggplot(data = valTemp, 
                       mapping = aes(codIns, fill = E))
    print(stackbar + geom_bar() +
            labs(y = "conta", x = NULL, fill = "risposta", 
                 title = paste(levels(VOSdati$codIns)[i], 
                    "Valutazione del corso\nA=≤18,B=19-21,C=22-25,D=26-29,E=30", 
                               sep = " ")))
    } else {
      cat("\n***** dati non disponibili *****\n")
    }
    cat("\n***** Domande informative *****\n") 
    cat("\n***** Gruppo 1: interesse, prerequisiti, frequenza *****\n")
    for (j in 1:dim(informative1)[1]){
      cat(as.character(informative1$Codice_domanda[j]), 
          informative1$Testo_domanda[j], "\n", sep = " ")
    }
    cat("\n***** Codici risposte *****\n")
    codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                         Codice_domanda == informative1$Codice_domanda[1])
    for (j in 1:dim(codRisTemp)[1]){
      cat(as.character(codRisTemp$Cod_risposta[j]), 
          codRisTemp$Testo_risposta[j], "\n", sep = " ")
    }
    infTemp <- subset(VOSinf1long, codIns == levels(VOSdati$codIns)[i])
    if(sum(complete.cases(infTemp))>0){
      stackbar <- ggplot(data = infTemp, 
                          mapping = aes(domanda, fill = codRisposta))
      print(stackbar + geom_bar() +
        labs(y = "conta", fill = "risposta", 
           title = paste(levels(VOSdati$codIns)[i], 
                         "Interesse, prerequisiti, frequenza", sep = " ")))
    } else {
      cat("\n***** dati non disponibili *****\n")
    }
    cat("\n***** Gruppo 2: materiale integrativo, esperti *****\n")
    for (j in 1:dim(informative2)[1]){
      cat(as.character(informative2$Codice_domanda[j]), 
          informative2$Testo_domanda[j], "\n", sep = " ")
    }
    cat("\n***** Codici risposte *****\n")
    codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                         Codice_domanda == informative2$Codice_domanda[1])
    for (j in 1:dim(codRisTemp)[1]){
      cat(as.character(codRisTemp$Cod_risposta[j]), 
          codRisTemp$Testo_risposta[j], "\n", sep = " ")
    }
    infTemp <- subset(VOSinf2long, codIns == levels(VOSdati$codIns)[i])
    if(sum(complete.cases(infTemp))>0){
      stackbar <- ggplot(data = infTemp, 
                       mapping = aes(domanda, fill = codRisposta))
      print(stackbar + geom_bar() +
        labs(y = "conta", fill = "risposta", 
           title = paste(levels(VOSdati$codIns)[i], 
                         "Materiale integrativo, esperti", sep = " ")))
    } else {
      cat("\n***** dati non disponibili *****\n")
    }
    cat("\n***** Gruppo 3 contatti con il docente*****\n")
    for (j in 1:dim(informative3)[1]){
      cat(as.character(informative3$Codice_domanda[j]), 
          informative3$Testo_domanda[j], "\n", sep = " ")
    }
    cat("\n***** Codici risposte *****\n")
    codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                         Codice_domanda == informative3$Codice_domanda[1])
    for (j in 1:dim(codRisTemp)[1]){
      cat(as.character(codRisTemp$Cod_risposta[j]), 
          codRisTemp$Testo_risposta[j], "\n", sep = " ")
    }
    infTemp <- subset(VOSinf3long, codIns == levels(VOSdati$codIns)[i])
    if(sum(complete.cases(infTemp))>0){
      stackbar <- ggplot(data = infTemp, 
                          mapping = aes(domanda, fill = codRisposta))
      print(stackbar + geom_bar() +
        labs(y = "conta", fill = "risposta", 
           title = paste(levels(VOSdati$codIns)[i], 
                         "Ha cercato il docente?", sep = " ")))
    } else {
      cat("\n***** dati non disponibili *****\n")
    }
    cat("\n***** Il docente è stato reperibile? *****\n")
    for (j in 1:dim(informative3_1)[1]){
      cat(as.character(informative3_1$Codice_domanda[j]), 
          informative3_1$Testo_domanda[j], "\n", sep = " ")
    }
    cat("\n***** Codici risposte *****\n")
    codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                         Codice_domanda == informative3_1$Codice_domanda[1])
    for (j in 1:dim(codRisTemp)[1]){
      cat(as.character(codRisTemp$Cod_risposta[j]), 
          codRisTemp$Testo_risposta[j], "\n", sep = " ")
    }
    infTemp <- subset(VOSinf3_1long, codIns == levels(VOSdati$codIns)[i])
    if(sum(complete.cases(infTemp))>0){
      stackbar <- ggplot(data = infTemp, 
                          mapping = aes(domanda, fill = codRisposta))
     print(stackbar + geom_bar() +
        labs(y = "conta", fill = "risposta", 
           title = paste(levels(VOSdati$codIns)[i], 
                         "Il docente è stato reperibile?", sep = " ")))
    } else {
      cat("\n***** dati non disponibili *****\n")
    }
    cat("\n***** Gruppo 4: carico didattico *****\n")
    for (j in 1:dim(informative4)[1]){
      cat(as.character(informative4$Codice_domanda[j]), 
          informative4$Testo_domanda[j], "\n", sep = " ")
    }
    cat("\n***** Codici risposte *****\n")
    codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                         Codice_domanda == informative4$Codice_domanda[1])
    for (j in 1:dim(codRisTemp)[1]){
      cat(as.character(codRisTemp$Cod_risposta[j]), 
          codRisTemp$Testo_risposta[j], "\n", sep = " ")
    }
    infTemp <- subset(VOSinf4long, codIns == levels(VOSdati$codIns)[i])
    if(sum(complete.cases(infTemp))>0){
      stackbar <- ggplot(data = infTemp, 
                          mapping = aes(domanda, fill = codRisposta))
      print(stackbar + geom_bar() +
        labs(y = "conta", fill = "risposta", 
           title = paste(levels(VOSdati$codIns)[i], 
                         "Carico didattico", sep = " ")))
    } else {
      cat("\n***** dati non disponibili *****\n")
    }
    if (inferenziali != "no"){
      cat("\nEsiste una relazione fra punteggio mediano e valutazione?\n")
      plot(E ~medval, 
           data = subset(VOSvalmedians, codIns == levels(VOSdati$codIns)[i]),
           main = paste(levels(VOSdati$codIns)[i], 
                        "E vs mediana valutative", sep = " "))
            print(cor.test(~ medval+E, 
               data = subset(VOSvalmedians, 
                            codIns == levels(VOSdati$codIns)[i]),
              method = "spearman"))
      cat("\nEsiste una relazione fra la frequenza al corso e la valutazione?\n")
      datatemp <- subset(cbind(VOSinf1wide,VOSvalcorso[,2],VOSvalwide[,4]), 
                         codIns == levels(VOSdati$codIns)[i])
      colnames(datatemp)[5:6] <- c("E","A4")
      cat("\nE vs B9 (frequenza al corso)\n")
      tabletemp <- xtabs(~ B9 + E, 
                         data = datatemp, drop.unused.levels = T)
      print(tabletemp)
      print(fisher.test(tabletemp))
      cat("\nE vs A2 (interesse al corso)\n")
      tabletemp <- xtabs(~ A2 + E, 
                         data = datatemp, drop.unused.levels = T)
      print(tabletemp)
      print(fisher.test(tabletemp))
      cat("\nE vs B1 (conoscenze preliminari)\n")
      tabletemp <- xtabs(~ B1 + E, 
                         data = datatemp, drop.unused.levels = T)
      print(tabletemp)
      print(fisher.test(tabletemp))
      cat("\nE vs A4 (soddisfazione generale)\n")
      tabletemp <- xtabs(~ A4 + E, 
                         data = datatemp, drop.unused.levels = T)
      print(tabletemp)
      print(fisher.test(tabletemp))
      }
  }
}
#########1#########2#########3#########4#########5#########6#########7#########8
# Questa sezione genera report riassuntivi per le domande informative e 
# valutative per tutti gli insegnamenti.
# L'analisi è condotta per anno di corso di studi.
# Da valutare se mettere un'opzione per inserire/omettere stacked bar plots.
#########1#########2#########3#########4#########5#########6#########7#########8
cat("\n***** Elenco dei corsi *****\n")
print(corsiMetadata)
cat("\n***** Domande valutative *****\n")
for (j in 1:dim(valutative)[1]){
  cat(as.character(valutative$Codice_domanda[j]), 
      valutative$Testo_domanda[j], "\n", sep = " ")
}
cat("\n***** Codici risposte *****\n")
codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                     Codice_domanda == valutative$Codice_domanda[1])
for (j in 1:dim(codRisTemp)[1]){
  cat(as.character(codRisTemp$Cod_risposta[j]), 
      codRisTemp$Testo_risposta[j], "\n", sep = " ")
}
maxanni <- max(corsiMetadata$anno)
for (i in 1:maxanni){
  insegnamenti <- subset(corsiMetadata, corsiMetadata$anno == i)[,2]
  selezione <- which(as.character(VOSvallong$codIns) 
                     %in% insegnamenti)
  VOSvaltemp <- VOSvallong[selezione,]
  VOSvaltemp$codIns <- as.factor(as.character(VOSvaltemp$codIns))
  selezione <- which(as.character(VOSvalnum$codIns) 
                     %in% insegnamenti)
  VOSvalnumtemp <- VOSvalnum[selezione,]
  VOSvalnumtemp$codIns <- as.factor(as.character(VOSvalnumtemp$codIns))
  stackbar <- ggplot(data = VOSvaltemp, 
                          mapping = aes(domanda, fill = codRisposta))
  print(stackbar + geom_bar() +
        facet_wrap(~codIns) +
        labs(y = "conta", fill = "risposta", 
             title = paste("Valutative", "anno", i, sep = " ")) +
    theme(axis.text.x  = element_text(angle=90, vjust=0.5)))
  # produce box plot per le domande valutative, per tutti i corsi
  # ordinato per domanda
  boxplot <- ggplot(data = VOSvalnumtemp, 
                  mapping = aes(x = codIns, y = codRisposta))
  print(boxplot + geom_boxplot(notch = T, na.rm = T) +
        facet_wrap(~domanda) +
        labs(y = "punteggio", fill = "domanda", 
             title = paste("Confronto fra insegnamenti","anno",i,sep = " ")) +
        theme(axis.text.x  = element_text(angle=90, vjust=0.5)))
}
cat("\n***** Domande informative *****\n") 
cat("\n***** Gruppo 1: interesse, prerequisiti, frequenza *****\n")
for (j in 1:dim(informative1)[1]){
  cat(as.character(informative1$Codice_domanda[j]), 
      informative1$Testo_domanda[j], "\n", sep = " ")
}
cat("\n***** Codici risposte *****\n")
codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                     Codice_domanda == informative1$Codice_domanda[1])
for (j in 1:dim(codRisTemp)[1]){
  cat(as.character(codRisTemp$Cod_risposta[j]), 
      codRisTemp$Testo_risposta[j], "\n", sep = " ")
}
for (i in 1:maxanni){
  insegnamenti <- subset(corsiMetadata, corsiMetadata$anno == i)[,2]
  selezione <- which(as.character(VOSinf1long$codIns) 
                     %in% insegnamenti)
  VOSinf1temp <- VOSinf1long[selezione,]
  VOSinf1temp$codIns <- as.factor(as.character(VOSinf1temp$codIns))
  stackbar <- ggplot(data = VOSinf1temp, 
                   mapping = aes(domanda, fill = codRisposta))
  print(stackbar + geom_bar() +
        facet_wrap(~codIns) +
        labs(y = "conta", fill = "risposta", 
             title = paste("Interesse, prerequisiti, frequenza,",
                           "anno",i,sep = " ")))
}
cat("\n***** Gruppo 2: materiale integrativo, esperti *****\n")
for (j in 1:dim(informative2)[1]){
  cat(as.character(informative2$Codice_domanda[j]), 
      informative2$Testo_domanda[j], "\n", sep = " ")
}
cat("\n***** Codici risposte *****\n")
codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                     Codice_domanda == informative2$Codice_domanda[1])
for (j in 1:dim(codRisTemp)[1]){
  cat(as.character(codRisTemp$Cod_risposta[j]), 
      codRisTemp$Testo_risposta[j], "\n", sep = " ")
}
for (i in 1:maxanni){
  insegnamenti <- subset(corsiMetadata, corsiMetadata$anno == i)[,2]
  selezione <- which(as.character(VOSinf2long$codIns) 
                     %in% insegnamenti)
  VOSinf2temp <- VOSinf2long[selezione,]
  VOSinf2temp$codIns <- as.factor(as.character(VOSinf2temp$codIns))
  stackbar <- ggplot(data = VOSinf2temp, 
                   mapping = aes(domanda, fill = codRisposta))
  print(stackbar + geom_bar() +
        facet_wrap(~codIns) +
        labs(y = "conta", fill = "risposta", 
             title = paste("Materiale integrativo, esperti,",
                           "anno",i, sep = " ")))
}
cat("\n***** Gruppo 3 contatti con il docente*****\n")
for (j in 1:dim(informative3)[1]){
  cat(as.character(informative3$Codice_domanda[j]), 
      informative3$Testo_domanda[j], "\n", sep = " ")
}
cat("\n***** Codici risposte *****\n")
codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                     Codice_domanda == informative3$Codice_domanda[1])
for (j in 1:dim(codRisTemp)[1]){
  cat(as.character(codRisTemp$Cod_risposta[j]), 
      codRisTemp$Testo_risposta[j], "\n", sep = " ")
}
for (i in 1:maxanni){
  insegnamenti <- subset(corsiMetadata, corsiMetadata$anno == i)[,2]
  selezione <- which(as.character(VOSinf3long$codIns) 
                     %in% insegnamenti)
  VOSinf3temp <- VOSinf3long[selezione,]
  VOSinf3temp$codIns <- as.factor(as.character(VOSinf3temp$codIns))
  stackbar <- ggplot(data = VOSinf3temp, 
                   mapping = aes(codIns, fill = codRisposta))
  print(stackbar + geom_bar() +
        labs(y = "conta", fill = "risposta", 
             title = paste("Ha cercato il docente?",
                           "anno", i, sep = " ")))
}
cat("\n***** Il docente è stato reperibile? *****\n")
for (j in 1:dim(informative3_1)[1]){
  cat(as.character(informative3_1$Codice_domanda[j]), 
      informative3_1$Testo_domanda[j], "\n", sep = " ")
}
cat("\n***** Codici risposte *****\n")
codRisTemp <- subset(Opinioni_metadata[,c(2,5:6)], 
                     Codice_domanda == informative3_1$Codice_domanda[1])
for (j in 1:dim(codRisTemp)[1]){
  cat(as.character(codRisTemp$Cod_risposta[j]), 
      codRisTemp$Testo_risposta[j], "\n", sep = " ")
}
for (i in 1:maxanni){
  insegnamenti <- subset(corsiMetadata, corsiMetadata$anno == i)[,2]
  selezione <- which(as.character(VOSinf3_1long$codIns) 
                     %in% insegnamenti)
  VOSinf3_1temp <- VOSinf3_1long[selezione,]
  VOSinf3_1temp$codIns <- as.factor(as.character(VOSinf3_1temp$codIns))
  stackbar <- ggplot(data = VOSinf3_1temp, 
                   mapping = aes(domanda, fill = codRisposta))
  print(stackbar + geom_bar() +
        facet_wrap(~codIns) +
        labs(y = "conta", fill = "risposta", 
             title = paste("Il docente è stato reperibile?",
                           "anno", i, sep = " "))) 
}
#########1#########2#########3#########4#########5#########6#########7#########8
# analisi riassuntive, tutti gli insegnamenti del corso di studi        
#########1#########2#########3#########4#########5#########6#########7#########8       
# punteggio globale per insegnamento
# volendo si potrebbe usare un fill diverso per tipologia
# di responsabile
VOSvalmedians2 <- VOSvalmedians[complete.cases(VOSvalmedians),]
boxplot <- ggplot(data = VOSvalmedians2, mapping = aes(codIns,medval))
boxplot + geom_boxplot(notch=T) +
  labs(x = "insegnamento", y = "punteggio mediano", fill = "domanda", 
       title = "Confronto fra insegnamenti, valutazione mediana") +
  theme(axis.text.x  = element_text(angle=90, vjust=0.5))
boxplot <- ggplot(data = VOSvalmedians2, mapping = aes(codIns, E))
boxplot + geom_boxplot(notch=T) +
  labs(x = "insegnamento", y = "punteggio mediano", fill = "domanda", 
  title = "Confronto fra insegnamenti, voto\n1 ≤18,2 =19-21,3=22-26,4=27-29,5 = 30") +
  theme(axis.text.x  = element_text(angle=90, vjust=0.5))

# resetta la wd
setwd(wd)
#########1#########2#########3#########4#########5#########6#########7#########8
# Crediti e citazioni                                                          #
# Script created by Eugenio Parente, 2016.                                     #
# Assume this is under GNU general public licence                              #
# http://www.gnu.org/licenses/gpl-3.0.en.html                                  #
#########1#########2#########3#########4#########5#########6#########7#########8